import { EventActivity } from "../types/EventActivity";
import { AppPageState, appStateSerialize } from "../lib/appState";
import { FormattingStyle, langDateFormatter } from "../lib/langDateFormatter";
import { Language } from "../types/Language";
import { UITranslation } from "../types/UITranslation";
import Link from "next/link";
import React, { FC } from "react";
import { textualJoiner } from "../lib/textualJoiner";
import { ConventionEdition } from "../types/ConventionEdition";
import { FlagsUI } from "../lib/flags";
import { TextWithColor } from "../types/TextWithColor";

type EventProps = {
  UIStrings: Record<Language, UITranslation>;
  lang: Language;
  event: EventActivity;
  conventionEdition: ConventionEdition;
  places: Record<string, TextWithColor>;
  showDay?: boolean;
};

export const Event: FC<EventProps> = ({
  event,
  lang,
  UIStrings,
  conventionEdition,
  places,
  showDay = false,
}) => (
  <Link
    key={event.uuid}
    href={`#${appStateSerialize([lang, AppPageState.detail, 0, event.uuid])}`}
  >
    <li className="event">
      <div className="time">
        {showDay && (
          <span className="timeDay">
            {langDateFormatter(
              FormattingStyle.DayOfWeek,
              lang,
              conventionEdition.timezone,
              event.time_start
            )}
          </span>
        )}
        <span className="timeStart">
          {langDateFormatter(
            FormattingStyle.HoursAndMinutes,
            lang,
            conventionEdition.timezone,
            event.time_start
          )}
        </span>
        <span className="timeEnd">
          {langDateFormatter(
            FormattingStyle.HoursAndMinutes,
            lang,
            conventionEdition.timezone,
            event.time_end
          )}
        </span>
      </div>
      <div className="details">
        <div className="title">{event.title[lang]}</div>
        <div className="secondLine">
          <div className="subtitle">
            {event.subtitle.uuid !== null
              ? event.subtitle[lang]
              : textualJoiner(
                  lang,
                  event.places.map((x) => places[x]).map((x) => x.label[lang])
                )}
          </div>
          {event.language !== conventionEdition.language && (
            <div className="language">
              {UIStrings[lang][FlagsUI[event.language]]}
            </div>
          )}
        </div>
      </div>
    </li>
  </Link>
);
