import { appStateParse } from "../lib/appState";
import {
  FormattingStyle,
  dateRecomposer,
  recomposedDateFormatter,
} from "../lib/langDateFormatter";
import { ConventionEdition } from "../types/ConventionEdition";
import { Language } from "../types/Language";
import { UITranslation } from "../types/UITranslation";
import { FC } from "react";
import { groupBy } from "../lib/groupBy";
import { sprintf } from "sprintf-js";
import { compare } from "../lib/compare";
import { Event } from "./Event";

type MasterFragmentDayProps = {
  UIStrings: Record<Language, UITranslation>;
  conventionEdition: ConventionEdition;
  day: Date;
};

export const MasterFragmentDay: FC<MasterFragmentDayProps> = ({
  UIStrings,
  conventionEdition,
  day,
}) => {
  const lang =
    appStateParse(window.location.hash.substring(1))?.[0] ??
    conventionEdition.language;
  const places = Object.fromEntries(
    conventionEdition.places.map((x) => [x.uuid, x])
  );
  const todayEvents = conventionEdition.events
    .sort(
      (a, b) =>
        compare(a.time_start.formatted, b.time_start.formatted) ||
        compare(a.time_end, b.time_end) ||
        compare(
          a.title[conventionEdition.language],
          b.title[conventionEdition.language]
        )
    )
    .filter((x) => {
      const t = dateRecomposer(
        conventionEdition.timezone,
        x.time_start
      ).getTime();
      const ds = day.getTime();
      const de = ds + 24 * 3600 * 1000;
      return ds <= t && t < de;
    });
  const dd = (24 * 3600 * 1000) / conventionEdition.split_day_into_n_parts;
  const hourlyEvents = groupBy(todayEvents, (ev) =>
    sprintf(
      "%02d",
      Math.floor(
        (dateRecomposer(conventionEdition.timezone, ev.time_start).getTime() -
          day.getTime()) /
          dd
      )
    )
  ).map((hourEvents) => ({
    hourStart:
      Math.floor(
        (dateRecomposer(
          conventionEdition.timezone,
          hourEvents[0].time_start
        ).getTime() -
          day.getTime()) /
          dd
      ) *
        dd +
      day.getTime(),
    hourEvents,
  }));
  return (
    <ul className="events">
      {hourlyEvents.map(({ hourStart, hourEvents }) => (
        <li key={hourStart}>
          <span>
            {recomposedDateFormatter(
              FormattingStyle.HoursAndMinutes,
              lang,
              new Date(hourStart)
            )}
          </span>
          <ul>
            {hourEvents.map((hourEvent) => (
              <Event
                key={hourEvent.uuid}
                UIStrings={UIStrings}
                lang={lang}
                event={hourEvent}
                conventionEdition={conventionEdition}
                places={places}
              />
            ))}
          </ul>
        </li>
      ))}
    </ul>
  );
};
