import { appStateParse } from "../lib/appState";
import { ConventionEdition } from "../types/ConventionEdition";
import { ConventionSeries } from "../types/ConventionSeries";
import Link from "next/link";
import Image from "next/image";
import { FC } from "react";
import { hexColorToFilter } from "../lib/hexColorToFilter";

type MasterFragmentSocialMediaProps = {
  conventionSeries: ConventionSeries;
  conventionEdition: ConventionEdition;
};

export const MasterFragmentSocialMedia: FC<MasterFragmentSocialMediaProps> = ({
  conventionSeries,
  conventionEdition,
}) => {
  const lang =
    appStateParse(window.location.hash.substring(1))?.[0] ??
    conventionEdition.language;
  return (
    <ul className="socials">
      {conventionSeries.social_medias.map((x) => (
        <Link
          key={`${x.alias}-${x.name[lang]}`}
          href={x.url[lang]}
          target="_blank"
          rel="noreferrer"
        >
          <li>
            <i
              className="icon"
              style={{
                maskImage: `url("/icons/${x.icon}.svg")`,
                WebkitMaskImage: `url("/icons/${x.icon}.svg")`,
                backgroundColor: x.color.color,
              }}
            />
            <div>
              <div>{x.name[lang]}</div>
              <div>{x.url[lang]}</div>
            </div>
          </li>
        </Link>
      ))}
    </ul>
  );
};
