import { ReactNode } from "react";
import { Language } from "../types/Language";
import { TextWithColor } from "../types/TextWithColor";
import { applyColorTo } from "./applyColorTo";

const MIDDLE = ", ";
const FINAL = {
  [Language.en]: " and ",
  [Language.es]: " y ",
  [Language.pt]: " e ",
} as const;

export const textualJoiner = (lang: Language, texts: string[]): string => {
  switch (texts.length) {
    case 0:
      return "";
    case 1:
      return texts[0];
    case 2:
      return `${texts[0]}${FINAL[lang]}${texts[1]}`;
    default:
      return `${texts[0]}${MIDDLE}${textualJoiner(lang, texts.slice(1))}`;
  }
};

export const textualColoredJoiner = (
  lang: Language,
  texts: TextWithColor[],
  altColors: string[]
): ReactNode => {
  switch (texts.length) {
    case 0:
      return <></>;
    case 1:
      return applyColorTo(lang, texts[0], altColors);
    case 2:
      return (
        <>
          {applyColorTo(lang, texts[0], altColors)}
          {FINAL[lang]}
          {applyColorTo(lang, texts[1], altColors)}
        </>
      );
    default:
      return (
        <>
          {applyColorTo(lang, texts[0], altColors)}
          {MIDDLE}
          {textualColoredJoiner(lang, texts.slice(1), altColors)}
        </>
      );
  }
};
